Range-v3: ranges::v3::concepts::Invocable Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Types | Public Member Functions | List of all members
ranges::v3::concepts::Invocable Struct Reference

## Public Types
template<typename Fun , typename... Args>
using | result_t = result_of_t< Fun &&(Args &&...)>

## Public Member Functions
template<typename Fun , typename... Args>
auto | requires_ () -> meta::void_< result_of_t< Fun &&(Args &&...)>>